@@ -5,8 +5,8 @@ fn main() {
         || 1,
         |count, cx| {
             vstack((
-                text(&format!("{}", cx[count])).padding(Auto),
-                button(text("increment"), move |cx| {
+                cx[count].padding(Auto),
+                button("increment", move |cx| {
                     cx[count] += 1;
                 })
                 .padding(Auto),
