@@ -3,7 +3,7 @@ use rui::*;
 #[derive(Clone, Copy)]
 enum MyControlType {
     Chill,
-    Agro
+    Agro,
 }
 
 impl Default for MyControlType {
@@ -18,25 +18,28 @@ trait MyMods: View + Sized {
 
 fn my_control() -> impl MyMods {
     modview(|t, _| {
-        circle().color( match t {
+        circle().color(match t {
             MyControlType::Chill => AZURE_HIGHLIGHT,
-            MyControlType::Agro => RED_HIGHLIGHT
+            MyControlType::Agro => RED_HIGHLIGHT,
         })
     })
 }
 
-impl<F> MyMods for ModView<MyControlType, F> where ModView<MyControlType, F>: View
+impl<F> MyMods for ModView<MyControlType, F>
+where
+    ModView<MyControlType, F>: View,
 {
     fn agro(self) -> Self {
-        ModView { func: self.func, value: MyControlType::Agro }
+        ModView {
+            func: self.func,
+            value: MyControlType::Agro,
+        }
     }
 }
 
 fn main() {
-    rui( 
-        vstack((
-            my_control().padding(Auto),
-            my_control().agro().padding(Auto)
-        ))
-    )
-}
\ No newline at end of file
+    rui(vstack((
+        my_control().padding(Auto),
+        my_control().agro().padding(Auto),
+    )))
+}
