@@ -5,7 +5,7 @@ fn main() {
         zstack((
             circle()
                 .color(RED_HIGHLIGHT.alpha(0.8))
-                .tap(|_, key_mods| println!("tapped circle, key modifiers state: {:?}", key_mods))
+                .tap(|cx| println!("tapped circle, key modifiers state: {:?}", cx.key_mods))
                 .padding(Auto),
             "Tap (inside circle)",
         )),
@@ -13,14 +13,17 @@ fn main() {
             rectangle()
                 .corner_radius(5.0)
                 .color(AZURE_HIGHLIGHT_BACKGROUND)
-                .drag(|_, delta, _state, key_mods, _mouse_button| {
-                    println!("dragging: {:?}, key modifiers state: {:?}", delta, key_mods)
+                .drag(|cx, delta, _state, _mouse_button| {
+                    println!(
+                        "dragging: {:?}, key modifiers state: {:?}",
+                        delta, cx.key_mods
+                    )
                 })
                 .padding(Auto),
             "Drag (inside rectangle)".padding(Auto),
         )),
         "Handle key pressed"
-            .key(|_, key, key_mods| println!("key: {:?}, key modifiers state: {:?}", key, key_mods))
+            .key(|cx, key| println!("key: {:?}, key modifiers state: {:?}", key, cx.key_mods))
             .padding(Auto),
     )));
 }
