@@ -1,6 +1,5 @@
 use crate::*;
 use accesskit::Role;
-use tao::event::MouseButton;
 
 pub trait Modifiers: View + Sized {
     /// Adds space around a view. Can be either `Auto` or `Px(number_of_pixels)`
@@ -9,7 +8,7 @@ pub trait Modifiers: View + Sized {
     }
 
     /// Calls a function in response to a tap.
-    fn tap<F: Fn(&mut Context, ModifiersState) + 'static>(self, f: F) -> Tap<Self, F> {
+    fn tap<F: Fn(&mut Context) + 'static>(self, f: F) -> Tap<Self, F> {
         Tap::new(self, f)
     }
 
@@ -25,9 +24,7 @@ pub trait Modifiers: View + Sized {
     }
 
     /// Calls a function in response to a drag.
-    fn drag<
-        F: Fn(&mut Context, LocalOffset, GestureState, ModifiersState, Option<MouseButton>) + 'static,
-    >(
+    fn drag<F: Fn(&mut Context, LocalOffset, GestureState, Option<MouseButton>) + 'static>(
         self,
         f: F,
     ) -> Drag<Self, F> {
@@ -48,7 +45,7 @@ pub trait Modifiers: View + Sized {
     fn command<F: Fn(&mut Context) + 'static>(
         self,
         name: &str,
-        key: Option<KeyCode>,
+        key: Option<HotKey>,
         f: F,
     ) -> Command<Self, F> {
         Command::new(self, name.into(), key, f)
@@ -60,8 +57,8 @@ pub trait Modifiers: View + Sized {
     }
 
     /// Responds to keyboard events
-    fn key<F: Fn(&mut Context, KeyPress, ModifiersState) + 'static>(self, f: F) -> Key<Self, F> {
-        Key::new(self, f)
+    fn key<F: Fn(&mut Context, Key) + 'static>(self, f: F) -> KeyView<Self, F> {
+        KeyView::new(self, f)
     }
 
     /// Specify an accessiblity role.
@@ -81,13 +78,18 @@ pub trait Modifiers: View + Sized {
 
     /// Add an environment value.
     fn env<E: Clone + 'static>(self, value: E) -> SetenvView<Self, E> {
-        SetenvView::new(self, Some(value))
+        SetenvView::new(self, value)
     }
 
-    /// Add an environment value.
-    fn env_mod<E: Clone + 'static>(self) -> SetenvView<Self, E> {
-        SetenvView::new(self, None)
+    /// Calls a closure after rendering with context and delta time.
+    fn anim<F: Fn(&mut Context, f32) + 'static>(self, func: F) -> AnimView<Self, F> {
+        AnimView::new(self, func)
+    }
+
+    /// Indicates that this item can expand within a stack.
+    fn flex(self) -> Flex<Self> {
+        Flex::new(self)
     }
 }
 
-impl<V: View> Modifiers for V {}
\ No newline at end of file
+impl<V: View> Modifiers for V {}
